clear all

% Explanation of the six files containing the parameter values used in the paper.

% The file 'Inputs20052014.xls' uses daily data from 2005-2014.
% It contains:
    % The expected return vector (first column); the last row is the risk-free rate; and
    % The variance-covariance matrix (last 12 columns).
% These data are consistent with the data reported in Table 1A.

% The file 'InputsQ22008Q12009.xls' uses daily data from Q2 2008-Q1 2009.
% It contains:
    % The stressed expected return vector (first column); the last row is the stressed risk-free rate; and
    % The stressed variance-covariance matrix (last 12 columns).
% These data are consistent with the data reported in Table 1B.

% The file 'Inputs1994.xls' uses daily data from 1994.
% It contains:
    % The stressed expected return vector (first column); the last row is the stressed risk-free rate; and
    % The stressed variance-covariance matrix (last 12 columns).
    
% The file 'Inputs19952004.xls' uses daily data from 1995-2004.
% It contains:
    % The expected return vector (first column); the last row is the risk-free rate; and
    % The variance-covariance matrix (last 12 columns).
    
% The file 'Inputs20072009.xls' uses daily data from 2007-2009.
% It contains:
    % The expected return vector (first column);
    % The standard deviation vector (second column); and
    % The correlation matrix (last 12 columns).
   
% The file 'Inputs20052006and20102014.xls' uses daily data from 2005-2006 and 2010-2014.
% It contains:
    % The expected return vector (first column);
    % The standard deviation vector (second column); and
    % The correlation matrix (last 12 columns).
    
% Daily average returns, variances, and covariances are scaled to a period of ten trading days by multiplying the daily statistics by 10.

Inputs20052014=xlsread('Inputs20052014');
miu=Inputs20052014(1:12,1);
rf=Inputs20052014(13,1);
sigma=Inputs20052014(1:12,2:13);

InputsQ22008Q12009=xlsread('InputsQ22008Q12009');
mius=InputsQ22008Q12009(1:12,1);
rfs=InputsQ22008Q12009(13,1);
sigmas=InputsQ22008Q12009(1:12,2:13);

Inputs1994=xlsread('Inputs1994');
miushat=Inputs1994(1:12,1);
rfshat=Inputs1994(13,1);
sigmashat=Inputs1994(1:12,2:13);

Inputs19952004=xlsread('Inputs19952004');
miuhat=Inputs19952004(1:12,1);
rfhat=Inputs19952004(13,1);
sigmahat=Inputs19952004(1:12,2:13);

Inputs20072009=xlsread('Inputs20072009');
AR200709=Inputs20072009(:,1);
SD200709=Inputs20072009(:,2);
CC200709=Inputs20072009(:,3:14);

Inputs20052006and20102014=xlsread('Inputs20052006and20102014');
AR200506201014=Inputs20052006and20102014(:,1);
SD200506201014=Inputs20052006and20102014(:,2);
CC200506201014=Inputs20052006and20102014(:,3:14);

N=12;% Number of risky assets
I=ones(N,1);% Unit vector

AVERAGEEXCESSKURT=5.429194;%Average excess kurtosis across risky assets
v=4+6/AVERAGEEXCESSKURT;%Degrees of freedom
yalpha=(v/(v-1))*tpdf(tinv(0.975,v),v)/(1-0.975)*(1+tinv(0.975,v)^2/v)*((v-2)/v)^0.5;%For determining CVaR at the 97.5% confidence level
zalpha=tinv(0.99,v)*((v-2)/v)^0.5;%For determining VaR at the 99% confidence level

% Changes in standard deviations, CVaRs, and correlation coefficients from the non-crisis period (2005-2006 and 2010-2014) to the crisis period (2007-2009)
% These statistics are reported at the beginning of Section 4.

%Relative changes in standard deviations
RelativeChangeSD=(SD200709./SD200506201014-I)*100;% Relative changes in the standard deviations of risky assets from the non-crisis period to the crisis period
MinRelativeChangeSD=min(RelativeChangeSD);% Minimum relative change
MaxRelativeChangeSD=max(RelativeChangeSD);% Maximum relative change
AveRelativeChangeSD=mean(RelativeChangeSD);% Average relative change

%Relative changes in CVaRs
CVaR200709=yalpha*SD200709-AR200709;%CVaRs of risky assets using data from 2007-2009
CVaR200506201014=yalpha*SD200506201014-AR200506201014;%CVaRs of risky assets using data from 2005-2006 and 2010-2014
RelativeChangeCVaR=(CVaR200709./CVaR200506201014-I)*100;% Relative changes in the CVaRs of risky assets from the non-crisis period to the crisis period
MinRelativeChangeCVaR=min(RelativeChangeCVaR);% Minimum relative change
MaxRelativeChangeCVaR=max(RelativeChangeCVaR);% Maximum relative change
AveRelativeChangeCVaR=mean(RelativeChangeCVaR);% Average relative change

%Pairs of assets involving just Treasury bonds
j1=1;
j3=1;
CPosTB=0;%Number of pairs of assets involving just Treasury bonds where relative changes in correlation coefficients are positive
while j1<7;
   j2=j1+1;
   while j2<7;
       if CC200709(j1,j2)>CC200506201014(j1,j2);
           CPosTB=CPosTB+1;
       end
       RelativeChangeCCTB(j1,j2)=(CC200709(j1,j2)/CC200506201014(j1,j2)-1)*100;
       RelativeChangeVectorCCTB(j3,1)=RelativeChangeCCTB(j1,j2);
       j3=j3+1;
   j2=j2+1;       
   end
   j1=j1+1;
end

MinRelativeChangeCCTB=min(RelativeChangeVectorCCTB);% Minimum relative change
MaxRelativeChangeCCTB=max(RelativeChangeVectorCCTB);% Maximum relative change
AveRelativeChangeCCTB=mean(RelativeChangeVectorCCTB);% Average relative change

%Pairs of assets involving just agency bonds
j1=7;
j4=1;
CPosAB=0;%Number of pairs of assets involving just agency bonds where relative changes in correlation coefficients are positive
while j1<13
   j2=j1+1;
   while j2<13
       if CC200709(j1,j2)>CC200506201014(j1,j2)
           CPosAB=CPosAB+1;
       end
       RelativeChangeCCAB(j1,j2)=(CC200709(j1,j2)/CC200506201014(j1,j2)-1)*100;
       RelativeChangeVectorCCAB(j4,1)=RelativeChangeCCAB(j1,j2);
       j4=j4+1;
   j2=j2+1;       
   end
   j1=j1+1;
end

MinRelativeChangeCCAB=min(RelativeChangeVectorCCAB);% Minimum relative change
MaxRelativeChangeCCAB=max(RelativeChangeVectorCCAB);% Maximum relative change
AveRelativeChangeCCAB=mean(RelativeChangeVectorCCAB);% Average relative change

% Pairs of assets involving just Treasury bonds or just agency bonds
MinRelativeChangeCCTBorAB=min(MinRelativeChangeCCTB,MinRelativeChangeCCAB);% Minimum relative change
MaxRelativeChangeCCTBorAB=max(MaxRelativeChangeCCTB,MaxRelativeChangeCCAB);% Maximum relative change
AveRelativeChangeCCTBorAB=(AveRelativeChangeCCTB+AveRelativeChangeCCAB)/2;% Average relative change
CPosTBorAB=CPosTB+CPosAB;% Number of pairs of assets involving just Treasury bonds or just agency bonds where relative changes in correlation coefficients are positive

%Pairs of assets involving both Treasury and agency bonds
j1=1;
j5=1;
CPosTBAB=0;%Number of pairs of assets involving both Treasury and agency bonds where relative changes in correlation coefficients are positive
while j1<7
   j2=7;
   while j2<13
       if CC200709(j1,j2)>CC200506201014(j1,j2)
           CPosTBAB=CPosTBAB+1;
       end
       RelativeChangeCCTBAB(j1,j2)=(CC200709(j1,j2)/CC200506201014(j1,j2)-1)*100;
       RelativeChangeVectorCCTBAB(j5,1)=RelativeChangeCCTBAB(j1,j2);
       j5=j5+1;
   j2=j2+1;       
   end
   j1=j1+1;
end

MinRelativeChangeCCTBAB=min(RelativeChangeVectorCCTBAB);% Minimum relative change
MaxRelativeChangeCCTBAB=max(RelativeChangeVectorCCTBAB);% Maximum relative change
AveRelativeChangeCCTBAB=mean(RelativeChangeVectorCCTBAB);% Average relative change

%Constants and portfolios useful to derive composition of portfolios on the M-V frontier
isigma=inv(sigma);%Inverse of the variance-covariance matrix
isigmas=inv(sigmas);%Inverse of the stressed variance-covariance matrix

a=miu'*isigma*I;
b=miu'*isigma*miu;
c=I'*isigma*I;
w0=isigma*I/c;
w1=isigma*miu/a;

wbar0=zeros(N,1);
wbar0(N+1,1)=1;
wbar1=isigma*(miu-I*rf)/(a-c*rf);
wbar1(N+1,1)=0;

%Constants and portfolios useful to derive composition of portfolios on the M-SCVaR frontier
as=miu'*isigmas*I;
bs=miu'*isigmas*miu;
cs=I'*isigmas*I;
ds=mius'*isigmas*I;
es=mius'*isigmas*mius;
fs=mius'*isigmas*miu;
gs=(2*as*ds*fs-bs*ds^2-cs*fs^2)/(bs*cs-as^2)+es;

w0s=isigmas*I/cs;
w1s=isigmas*miu/as;
w2s=isigmas*mius/ds;

%Derivation of portolios on the M-V and M-SCVaR frontiers
NE=20000;%Number of levels of expected return (minus one) between zero and 1%
e=1;
while e<NE+2;
E(e)=(e-1)*0.01/NE;%Required expected return

%Portfolios on the M-V frontier
thetaE(e)=(E(e)-b/a)/(a/c-b/a);
wE(:,e)=thetaE(e)*w0+(1-thetaE(e))*w1;%Equarion (1)

%Statistics of portfolios on the M-V frontier
ERwE(e)=wE(:,e)'*miu;%Expected return
SDwE(e)=(wE(:,e)'*sigma*wE(:,e))^0.5;%Standard deviation
CwE(e)=yalpha*SDwE(e)-ERwE(e);%CVaR
VwE(e)=zalpha*SDwE(e)-ERwE(e);%VaR
ERswE(e)=wE(:,e)'*mius;%Stressed expected return
SDswE(e)=(wE(:,e)'*sigmas*wE(:,e))^0.5;%Stressed standard deviation
CswE(e)=yalpha*SDswE(e)-ERswE(e);%SCVaR
VswE(e)=zalpha*SDswE(e)-ERswE(e);%SVaR
ERshatwE(e)=wE(:,e)'*miushat;%Stressed expected return (1994)
SDshatwE(e)=(wE(:,e)'*sigmashat*wE(:,e))^0.5;%Stressed standard deviation (1994)
CshatwE(e)=yalpha*SDshatwE(e)-ERshatwE(e);%SCVaR (1994)
ERhatwE(e)=wE(:,e)'*miuhat;%Expected return (1995-2004)
SDhatwE(e)=(wE(:,e)'*sigmahat*wE(:,e))^0.5;%Standard deviation (1995-2004)
VhatwE(e)=zalpha*SDhatwE(e)-ERhatwE(e);%VaR (1995-2004)

%Portfolios on the M-SCVaR frontier
hs=(cs*E(e)^2-2*as*E(e)+bs)/(bs*cs-as^2);
lambda1(e)=((bs-as*E(e))+(as*fs-bs*ds)*(hs/(yalpha^2-gs))^0.5)/(bs*cs-as^2);%Equation (34) of online appendix
lambda2(e)=((cs*E(e)-as)+(as*ds-cs*fs)*(hs/(yalpha^2-gs))^0.5)/(bs*cs-as^2);%Equation (35) of online appendix
lambda3(e)=(hs/(yalpha^2-gs))^0.5;%Equation (36) of online appendix
theta0alphaE(e)=cs*lambda1(e);%Equation (37) of online appendix
theta1alphaE(e)=as*lambda2(e);%Equation (38) of online appendix
theta2alphaE(e)=ds*lambda3(e);%Equation (39) of online appendix
walphaE(:,e)=theta0alphaE(e)*w0s+theta1alphaE(e)*w1s+(1-theta0alphaE(e)-theta1alphaE(e))*w2s;;%Equation (5) of paper

%Statistics of portfolios on the M-SCVaR frontier
ERwalphaE(e)=walphaE(:,e)'*miu;%Expected return
SDwalphaE(e)=(walphaE(:,e)'*sigma*walphaE(:,e))^0.5;%Standard deviation
CwalphaE(e)=yalpha*SDwalphaE(e)-ERwalphaE(e);%CVaR
VwalphaE(e)=zalpha*SDwalphaE(e)-ERwalphaE(e);%VaR
ERswalphaE(e)=walphaE(:,e)'*mius;%Stressed expected return
SDswalphaE(e)=(walphaE(:,e)'*sigmas*walphaE(:,e))^0.5;%Stressed standard deviation
CswalphaE(e)=yalpha*SDswalphaE(e)-ERswalphaE(e);%SCVaR
VswalphaE(e)=zalpha*SDswalphaE(e)-ERswalphaE(e);%SVaR
ERshatwalphaE(e)=walphaE(:,e)'*miushat;%Stressed expected return (1994)
SDshatwalphaE(e)=(walphaE(:,e)'*sigmashat*walphaE(:,e))^0.5;%Stressed standard deviation (1994)
CshatwalphaE(e)=yalpha*SDshatwalphaE(e)-ERshatwalphaE(e);%SCVaR (1994)
ERhatwalphaE(e)=walphaE(:,e)'*miuhat;%Expected return (1995-2004)
SDhatwalphaE(e)=(walphaE(:,e)'*sigmahat*walphaE(:,e))^0.5;%Standard deviation (1995-2004)
VhatwalphaE(e)=zalpha*SDhatwalphaE(e)-ERhatwalphaE(e);%VaR (1995-2004)

%Quantities reported in Figures 2-8

%Relative increase in standard deviation when using the M-SCVaR frontier instead of the M-V frontier (Figure 2A)
RISD(e)=SDwalphaE(e)/SDwE(e)-1;

%Relative decrease in SCVaR when using the M-SCVaR frontier instead of the M-V frontier (Figure 3A)
RDSC(e)=(CswE(e)-CswalphaE(e))/CswE(e);

%Relative increase in the ratio of standard deviation to SCVaR when using the M-SCVaR frontier instead of the M-V frontier (Figure 4A)
RIRSDSC(e)=(SDwalphaE(e)/CswalphaE(e)-SDwE(e)/CswE(e))/(SDwE(e)/CswE(e));

%Relative increase in the ratio of CVaR to SCVaR when using the M-SCVaR frontier instead of the M-V frontier (Figure 5A)
RIRCSC(e)=(CwalphaE(e)/CswalphaE(e)-CwE(e)/CswE(e))/(CwE(e)/CswE(e));

%Relative change in the ratio of SCVaR (1994) to SCVaR when using the M-SCVaR frontier instead of the M-V frontier (Figure 6A)
RCRCshatCs(e)=(CshatwalphaE(e)/CswalphaE(e)-CshatwE(e)/CswE(e))/(CshatwE(e)/CswE(e));

%Relative change in minimum capital requirement when basing it on SCVaR instead of both VaR and SVaR (Figure 7A)
RCMCREVVs(e)=CswE(e)/(VwE(e)+VswE(e))-1;%Portfolio on M-V frontier
RCMCRalphaEVVs(e)=CswalphaE(e)/(VwalphaE(e)+VswalphaE(e))-1;%Portfolio on M-SCVaR frontier

%Relative change in minimum capital requirement when basing it on SCVaR instead of just VaR (Figure 7B)
RCMCREV(e)=CswE(e)/VwE(e)-1;%Portfolio on M-V frontier
RCMCRalphaEV(e)=CswalphaE(e)/VwalphaE(e)-1;%Portfolio on M-SCVaR frontier

%Relative change in minimum capital requirement based on both VaR and SVaR from a period not including the crisis to a period including the crisis (Figure 8A)
RCMCREVhatVsVVs(e)=(VwE(e)+VswE(e))/(VhatwE(e)+VswE(e))-1;%Portfolio on M-V frontier
RCMCRalphaEVhatVsVVs(e)=(VwalphaE(e)+VswalphaE(e))/(VhatwalphaE(e)+VswalphaE(e))-1;%Portfolio on M-SCVaR frontier

%Relative change in minimum capital requirement based on just VaR from a period not including the crisis to a period including the crisis (Figure 8B)
RCMCREVhatV(e)=VwE(e)/VhatwE(e)-1;%Portfolio on M-V frontier
RCMCRalphaEVhatV(e)=VwalphaE(e)/VhatwalphaE(e)-1;%Portfolio on M-SCVaR frontier

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%% PRESENCE OF A RISK-FREE ASSET %%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Portfolios on the M-V frontier
thetabarE(e)=(E(e)-(b-a*rf)/(a-c*rf))/(rf-(b-a*rf)/(a-c*rf));
wbarE(:,e)=thetabarE(e)*wbar0+(1-thetabarE(e))*wbar1;%Equarion (6)

%Statistics of portfolios on the M-V frontier
ERwbarE(e)=wbarE(1:N,e)'*miu+wbarE(N+1,e)*rf;%Expected return
SDwbarE(e)=(wbarE(1:N,e)'*sigma*wbarE(1:N,e))^0.5;%Standard deviation
CwbarE(e)=yalpha*SDwbarE(e)-ERwbarE(e);%CVaR
VwbarE(e)=zalpha*SDwbarE(e)-ERwbarE(e);%VaR
ERswbarE(e)=wbarE(1:N,e)'*mius+wbarE(N+1,e)*rfs;%Stressed expected return
SDswbarE(e)=(wbarE(1:N,e)'*sigmas*wbarE(1:N,e))^0.5;%Stressed standard deviation
CswbarE(e)=yalpha*SDswbarE(e)-ERswbarE(e);%SCVaR
VswbarE(e)=zalpha*SDswbarE(e)-ERswbarE(e);%SVaR
ERshatwbarE(e)=wbarE(1:N,e)'*miushat+wbarE(N+1,e)*rfshat;%Stressed expected return (1994)
SDshatwbarE(e)=(wbarE(1:N,e)'*sigmashat*wbarE(1:N,e))^0.5;%Stressed standard deviation (1994)
CshatwbarE(e)=yalpha*SDshatwbarE(e)-ERshatwbarE(e);%SCVaR (1994)
ERhatwbarE(e)=wbarE(1:N,e)'*miuhat+wbarE(N+1,e)*rfhat;%Expected return (1995-2004)
SDhatwbarE(e)=(wbarE(1:N,e)'*sigmahat*wbarE(1:N,e))^0.5;%Standard deviation (1995-2004)
VhatwbarE(e)=zalpha*SDhatwbarE(e)-ERhatwbarE(e);%VaR (1995-2004)

%Constants and portfolios useful to derive composition of portfolios on the M-SCVaR frontier
js=cs*rf^2-2*as*rf+bs;
ks=cs*rf*rfs-as*rfs-ds*rf+fs;
ls=cs*rfs^2-2*ds*rfs+es;
gbars=ls-ks^2/js;

wbar0=zeros(N,1);
wbar0(N+1,1)=1;
wbar1s=((miu-I*rf)'*isigmas/(as-cs*rf))';
wbar1s(N+1,1)=0;
wbar2s=((mius-I*rfs)'*isigmas/(ds-cs*rfs))';
wbar2s(N+1,1)=0;

%Portfolios on the M-SCVaR frontier
lambda4(e)=((E(e)-rf)-ks*((E(e)-rf)^2/(js*(yalpha^2-gbars)))^0.5)/js;% Equation (69) of online appendix
lambda5(e)=((E(e)-rf)^2/(js*(yalpha^2-gbars)))^0.5;% Equation (70) of online appendix
thetabar0alphaE(e)=1-(as-cs*rf)*lambda4(e)-(ds-cs*rfs)*lambda5(e);% Equation (71) of online appendix
thetabar1alphaE(e)=(as-cs*rf)*lambda4(e);% Equation (72) of online appendix
thetabar2alphaE(e)=(ds-cs*rfs)*lambda5(e);% Equation (73) of online appendix
wbaralphaE(:,e)=thetabar0alphaE(e)*wbar0+thetabar1alphaE(e)*wbar1s+(1-thetabar0alphaE(e)-thetabar1alphaE(e))*wbar2s;% Equation (7) of paper

%Statistics of portfolios on the M-SCVaR frontier
ERwbaralphaE(e)=wbaralphaE(1:N,e)'*miu+wbaralphaE(N+1,e)*rf;%Expected return
SDwbaralphaE(e)=(wbaralphaE(1:N,e)'*sigma*wbaralphaE(1:N,e))^0.5;%Standard deviation
CwbaralphaE(e)=yalpha*SDwbaralphaE(e)-ERwbaralphaE(e);%CVaR
VwbaralphaE(e)=zalpha*SDwbaralphaE(e)-ERwbaralphaE(e);%VaR
ERswbaralphaE(e)=wbaralphaE(1:N,e)'*mius+wbaralphaE(N+1,e)*rfs;%Stessed expected return
SDswbaralphaE(e)=(wbaralphaE(1:N,e)'*sigmas*wbaralphaE(1:N,e))^0.5;%Stessed standard deviation
CswbaralphaE(e)=yalpha*SDswbaralphaE(e)-ERswbaralphaE(e);%SCVaR
VswbaralphaE(e)=zalpha*SDswbaralphaE(e)-ERswbaralphaE(e);%SVaR
ERshatwbaralphaE(e)=wbaralphaE(1:N,e)'*miushat+wbaralphaE(N+1,e)*rfshat;%Stressed expected return (1994)
SDshatwbaralphaE(e)=(wbaralphaE(1:N,e)'*sigmashat*wbaralphaE(1:N,e))^0.5;%Stressed standard deviation (1994)
CshatwbaralphaE(e)=yalpha*SDshatwbaralphaE(e)-ERshatwbaralphaE(e);%SCVaR (1994)
ERhatwbaralphaE(e)=wbaralphaE(1:N,e)'*miuhat+wbaralphaE(N+1,e)*rfhat;%Expected return (1995-2004)
SDhatwbaralphaE(e)=(wbaralphaE(1:N,e)'*sigmahat*wbaralphaE(1:N,e))^0.5;%Standard deviation (1995-2004)
VhatwbaralphaE(e)=zalpha*SDhatwbaralphaE(e)-ERhatwbaralphaE(e);%VaR (1995-2004)

%Quantities reported in Figures 2-8

%Relative increase in standard deviation when using the M-SCVaR frontier instead of the M-V frontier (Figure 2B)
RISDbar(e)=SDwbaralphaE(e)/SDwbarE(e)-1;

%Relative decrease in SCVaR when using the M-SCVaR frontier instead of the M-V frontier (Figure 3B)
RDSCbar(e)=(CswbarE(e)-CswbaralphaE(e))/CswbarE(e);

%Relative increase in the ratio of standard deviation to SCVaR when using the M-SCVaR frontier instead of the M-V frontier (Figure 4B)
RIRSDSCbar(e)=(SDwbaralphaE(e)/CswbaralphaE(e)-SDwbarE(e)/CswbarE(e))/(SDwbarE(e)/CswbarE(e));

%Relative increase in the ratio of CVaR to SCVaR when using the M-SCVaR frontier instead of the M-V frontier (Figure 5B)
RIRCSCbar(e)=(CwbaralphaE(e)/CswbaralphaE(e)-CwbarE(e)/CswbarE(e))/(CwbarE(e)/CswbarE(e));

%Relative change in the ratio of SCVaR (1994) to SCVaR when using the M-SCVaR frontier instead of the M-V frontier (Figure 6B)
RCRCshatCsbar(e)=(CshatwbaralphaE(e)/CswbaralphaE(e)-CshatwbarE(e)/CswbarE(e))/(CshatwbarE(e)/CswbarE(e));

%Relative change in minimum capital requirement when basing it on SCVaR instead of both VaR and SVaR (Figure 7C)
RCMCREVVsbar(e)=CswbarE(e)/(VwbarE(e)+VswbarE(e))-1;%Portfolio on M-V frontier
RCMCRalphaEVVsbar(e)=CswbaralphaE(e)/(VwbaralphaE(e)+VswbaralphaE(e))-1;%Portfolio on M-SCVaR frontier

%Relative change in minimum capital requirement when basing it on SCVaR instead of just VaR (Figure 7D)
RCMCREVbar(e)=CswbarE(e)/VwbarE(e)-1;%Portfolio on M-V frontier
RCMCRalphaEVbar(e)=CswbaralphaE(e)/VwbaralphaE(e)-1;%Portfolio on M-SCVaR frontier

%Relative change in minimum capital requirement based on both VaR and SVaR from a period not including the crisis to a period including the crisis (Figure 8C)
RCMCREVhatVsVVsbar(e)=(VwbarE(e)+VswbarE(e))/(VhatwbarE(e)+VswbarE(e))-1;%Portfolio on M-V frontier
RCMCRalphaEVhatVsVVsbar(e)=(VwbaralphaE(e)+VswbaralphaE(e))/(VhatwbaralphaE(e)+VswbaralphaE(e))-1;%Portfolio on M-SCVaR frontier

%Relative change in minimum capital requirement based on just VaR from a period not including the crisis to a period including the crisis (Figure 8D)
RCMCREVhatVbar(e)=VwbarE(e)/VhatwbarE(e)-1;%Portfolio on M-V frontier
RCMCRalphaEVhatVbar(e)=VwbaralphaE(e)/VhatwbaralphaE(e)-1;%Portfolio on M-SCVaR frontier

e=e+1;
end

%%%% Figures %%%%
PLOTFIGURES=0;
%If PLOTFIGURES=1, figures are plotted
if PLOTFIGURES==1

%M-V and M-SCVaR frontier in M-SD space
figure1A = figure;
axes1A = axes('Parent',figure1A,'LineWidth',3,...
    'YTickLabel',{'0 ','0.2 ','0.4 ','0.6 ','0.8 ','1 '},...
    'YTick',[0 0.2 0.4 0.6 0.8 1],...
    'FontSize',40,...
    'FontName','Times new roman',...
    'Position',[0.14875 0.129709543568465 0.775000000000001 0.815]);% xlim(axes1,[0 7]);
box(axes1A,'on');
hold(axes1A,'all');
annotation(figure1A,'textbox',...
    [0.00677083333333333 0.881499101830823 0.0994047619047619 0.0992108229988726],...
    'Interpreter','none',...
    'String',{'Expected   ','return'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure1A,'textbox',...
    [0.716145833333333 0 0.2240625 0.0663900398243513],...
    'Interpreter','none',...
    'String',{'Standard deviation'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(SDwE*100,ERwE*100,SDwalphaE*100,ERwalphaE*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 7 0 1])

%M-V and M-SCVaR frontier in M-SCVaR space
figure1B = figure;
axes1B = axes('Parent',figure1B,'LineWidth',3,...
    'YTickLabel',{'0 ','0.2 ','0.4 ','0.6 ','0.8 ','1 '},...
    'YTick',[0 0.2 0.4 0.6 0.8 1],...
    'FontSize',40,...
    'FontName','Times new roman',...
    'Position',[0.14875 0.129709543568465 0.775000000000001 0.815]);% xlim(axes1,[0 7]);
box(axes1B,'on');
hold(axes1B,'all');
annotation(figure1B,'textbox',...
    [0.00677083333333333 0.881499101830823 0.0994047619047619 0.0992108229988726],...
    'Interpreter','none',...
    'String',{'Expected   ','return'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure1B,'textbox',...
    [0.845833333333333 0 0.0943749999999992 0.0663900398243513],...
    'String',{'SCVaR'},...
    'LineStyle','none',...
    'Interpreter','none',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off');
plot(CswE*100,ERwE*100,CswalphaE*100,ERwalphaE*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([-5 30 0 1])

%M-V and M-SCVaR frontier in M-SD space
figure1C = figure;
axes1C = axes('Parent',figure1C,'LineWidth',3,...
    'YTickLabel',{'0 ','0.2 ','0.4 ','0.6 ','0.8 ','1 '},...
    'YTick',[0 0.2 0.4 0.6 0.8 1],...
    'FontSize',40,...
    'FontName','Times new roman',...
    'Position',[0.14875 0.129709543568465 0.775000000000001 0.815]);% xlim(axes1,[0 7]);
box(axes1C,'on');
hold(axes1C,'all');
annotation(figure1C,'textbox',...
    [0.00677083333333333 0.881499101830823 0.0994047619047619 0.0992108229988726],...
    'Interpreter','none',...
    'String',{'Expected   ','return'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure1C,'textbox',...
    [0.716145833333333 0 0.2240625 0.0663900398243513],...
    'Interpreter','none',...
    'String',{'Standard deviation'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(SDwbarE*100,ERwbarE*100,SDwbaralphaE*100,ERwbaralphaE*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 7 0 1])

%M-V and M-SCVaR frontier in M-SCVaR space
figure1D = figure;
axes1D = axes('Parent',figure1D,'LineWidth',3,...
    'YTickLabel',{'0 ','0.2 ','0.4 ','0.6 ','0.8 ','1 '},...
    'YTick',[0 0.2 0.4 0.6 0.8 1],...
    'FontSize',40,...
    'FontName','Times new roman',...
    'Position',[0.14875 0.129709543568465 0.775000000000001 0.815]);% xlim(axes1,[0 7]);
box(axes1D,'on');
hold(axes1D,'all');
annotation(figure1D,'textbox',...
    [0.00677083333333333 0.881499101830823 0.0994047619047619 0.0992108229988726],...
    'Interpreter','none',...
    'String',{'Expected   ','return'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure1D,'textbox',...
    [0.845833333333333 0 0.0943749999999992 0.0663900398243513],...
    'String',{'SCVaR'},...
    'LineStyle','none',...
    'Interpreter','none',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off');
plot(CswbarE*100,ERwbarE*100,CswbaralphaE*100,ERwbaralphaE*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([-5 30 0 1])

% Relative increase in standard deviation
figure2A = figure;
axes2A = axes('Parent',figure2A,'LineWidth',3,...
    'YTickLabel',{'0 ','5 ','10 ','15 ','20 ','25 ', '30 ','35 '},...
    'YTick',[0 5 10 15 20 25 30 35],...
    'XTickLabel',{'0','0.2','0.4','0.6','0.8','1','1.2'},...
    'XTick',[0 0.2 0.4 0.6 0.8 1],...
    'Position',[0.291666666666667 0.136970954356846 0.680000000000001 0.815],'FontSize',40,...
    'FontName','Times new roman');%% Uncomment the following line to preserve the X-limits of the axes
box(axes2A,'on');
hold(axes2A,'all');
annotation(figure2A,'textbox',...
    [0.0015625 0.761057246393132 0.230208333333333 0.229122055674518],...
    'String',{'Relative increase in','standard deviation '},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'LineStyle','none');
annotation(figure2A,'textbox',...
    [0.792708333333333 0.00977755162850643 0.1859375 0.0588865096359743],...
    'String',{'Expected return'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(E*100,RISD*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 0 35])

figure2B = figure;
axes2B = axes('Parent',figure2B,'LineWidth',3,...
    'YTickLabel',{'0 ','5 ','10 ','15 ','20 ','25 ', '30 ','35 '},...
    'YTick',[0 5 10 15 20 25 30 35],...
    'XTickLabel',{'0','0.2','0.4','0.6','0.8','1','1.2'},...
    'XTick',[0 0.2 0.4 0.6 0.8 1],...
    'Position',[0.291666666666667 0.136970954356846 0.680000000000001 0.815],'FontSize',40,...
    'FontName','Times new roman');%% Uncomment the following line to preserve the X-limits of the axes
box(axes2B,'on');
hold(axes2B,'all');
annotation(figure2B,'textbox',...
    [0.0015625 0.761057246393132 0.230208333333333 0.229122055674518],...
    'String',{'Relative increase in','standard deviation '},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'LineStyle','none');
annotation(figure2B,'textbox',...
    [0.792708333333333 0.00977755162850643 0.1859375 0.0588865096359743],...
    'String',{'Expected return'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(E(E<rf)*100,RISDbar(E<rf)*100,'--',E(E>rf)*100,RISDbar(E>rf)*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 0 35])

% Relative decrease in SCVaR
figure3A = figure;
axes3A = axes('Parent',figure3A,'LineWidth',3,...
    'YTickLabel',{'0 ','5 ','10 ','15 ','20 ','25 ', '30 ','35 '},...
    'YTick',[0 5 10 15 20 25 30 35],...
    'XTickLabel',{'0','0.2','0.4','0.6','0.8','1','1.2'},...
    'XTick',[0 0.2 0.4 0.6 0.8 1],...
    'Position',[0.291666666666667 0.136970954356846 0.680000000000001 0.815],'FontSize',40,...
    'FontName','Times new roman');%% Uncomment the following line to preserve the X-limits of the axes
box(axes3A,'on');
hold(axes3A,'all');
annotation(figure3A,'textbox',...
    [0.0015625 0.761057246393132 0.230208333333333 0.229122055674518],...
    'String',{'Relative decrease in','SCVaR'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'LineStyle','none');
annotation(figure3A,'textbox',...
    [0.792708333333333 0.00977755162850643 0.1859375 0.0588865096359743],...
    'String',{'Expected return'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(E*100,RDSC*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 0 25])

figure3B = figure;
axes3B = axes('Parent',figure3B,'LineWidth',3,...
    'YTickLabel',{'0 ','5 ','10 ','15 ','20 ','25 ', '30 ','35 '},...
    'YTick',[0 5 10 15 20 25 30 35],...
    'XTickLabel',{'0','0.2','0.4','0.6','0.8','1','1.2'},...
    'XTick',[0 0.2 0.4 0.6 0.8 1],...
    'Position',[0.291666666666667 0.136970954356846 0.680000000000001 0.815],'FontSize',40,...
    'FontName','Times new roman');%% Uncomment the following line to preserve the X-limits of the axes
box(axes3B,'on');
hold(axes3B,'all');
annotation(figure3B,'textbox',...
    [0.0015625 0.761057246393132 0.230208333333333 0.229122055674518],...
    'String',{'Relative decrease in','SCVaR'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'LineStyle','none');
annotation(figure3B,'textbox',...
    [0.792708333333333 0.00977755162850643 0.1859375 0.0588865096359743],...
    'String',{'Expected return'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
E1=rf-0.00002;
E2=rf+0.00002;
plot(E(E<E1)*100,RDSCbar(E<E1)*100,'--',E(E>E2)*100,RDSCbar(E>E2)*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 0 25])

% Relative increase in the ratio of standard deviation to SCVaR
figure4A = figure;
axes4A = axes('Parent',figure4A,'LineWidth',3,...
    'YTickLabel',{'0 ','20 ','40 ','60 ','80 '},...
    'YTick',[0 20 40 60 80],...
    'XTickLabel',{'0','0.2','0.4','0.6','0.8','1','1.2'},...
    'XTick',[0 0.2 0.4 0.6 0.8 1],...
    'Position',[0.291666666666667 0.136970954356846 0.680000000000001 0.815],'FontSize',40,...
    'FontName','Times new roman');%% Uncomment the following line to preserve the X-limits of the axes
box(axes4A,'on');
hold(axes4A,'all');
annotation(figure4A,'textbox',...
    [0.0015625 0.761057246393132 0.230208333333333 0.229122055674518],...
    'String',{'Relative increase in','the ratio of standard','deviation to SCVaR'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'LineStyle','none');
annotation(figure4A,'textbox',...
    [0.792708333333333 0.00977755162850643 0.1859375 0.0588865096359743],...
    'String',{'Expected return'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(E*100,RIRSDSC*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 0 80])

figure4B = figure;
axes4B = axes('Parent',figure4B,'LineWidth',3,...
    'YTickLabel',{'0 ','20 ','40 ','60 ','80 '},...
    'YTick',[0 20 40 60 80],...
    'XTickLabel',{'0','0.2','0.4','0.6','0.8','1','1.2'},...
    'XTick',[0 0.2 0.4 0.6 0.8 1],...
    'Position',[0.291666666666667 0.136970954356846 0.680000000000001 0.815],'FontSize',40,...
    'FontName','Times new roman');%% Uncomment the following line to preserve the X-limits of the axes
box(axes4B,'on');
hold(axes4B,'all');
annotation(figure4B,'textbox',...
    [0.0015625 0.761057246393132 0.230208333333333 0.229122055674518],...
    'String',{'Relative increase in','the ratio of standard','deviation to SCVaR'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'LineStyle','none');
annotation(figure4B,'textbox',...
    [0.792708333333333 0.00977755162850643 0.1859375 0.0588865096359743],...
    'String',{'Expected return'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
E1=rf-0.000016;
E2=rf+0.00002;
plot(E(E<E1)*100,RIRSDSCbar(E<E1)*100,'--',E(E>E2)*100,RIRSDSCbar(E>E2)*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 0 80])

% Relative increase in the ratio of CVaR to SCVaR
figure5A = figure;
axes5A = axes('Parent',figure5A,'LineWidth',3,...
    'YTickLabel',{'0 ','20 ','40 ','60 ','80 '},...
    'YTick',[0 20 40 60 80],...
    'XTickLabel',{'0','0.2','0.4','0.6','0.8','1','1.2'},...
    'XTick',[0 0.2 0.4 0.6 0.8 1],...
    'Position',[0.291666666666667 0.136970954356846 0.680000000000001 0.815],'FontSize',40,...
    'FontName','Times new roman');%% Uncomment the following line to preserve the X-limits of the axes
box(axes5A,'on');
hold(axes5A,'all');
annotation(figure5A,'textbox',...
    [0.0015625 0.761057246393132 0.230208333333333 0.229122055674518],...
    'String',{'Relative increase in','the ratio of  CVaR','to SCVaR'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'LineStyle','none');
annotation(figure5A,'textbox',...
    [0.792708333333333 0.00977755162850643 0.1859375 0.0588865096359743],...
    'String',{'Expected return'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(E*100,RIRCSC*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 0 80])

figure5B = figure;
axes5B = axes('Parent',figure5B,'LineWidth',3,...
    'YTickLabel',{'0 ','20 ','40 ','60 ','80 '},...
    'YTick',[0 20 40 60 80],...
    'XTickLabel',{'0','0.2','0.4','0.6','0.8','1','1.2'},...
    'XTick',[0 0.2 0.4 0.6 0.8 1],...
    'Position',[0.291666666666667 0.136970954356846 0.680000000000001 0.815],'FontSize',40,...
    'FontName','Times new roman');%% Uncomment the following line to preserve the X-limits of the axes
box(axes5B,'on');
hold(axes5B,'all');
annotation(figure5B,'textbox',...
    [0.0015625 0.761057246393132 0.230208333333333 0.229122055674518],...
    'String',{'Relative increase in','the ratio of  CVaR','to SCVaR'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'LineStyle','none');
annotation(figure5B,'textbox',...
    [0.792708333333333 0.00977755162850643 0.1859375 0.0588865096359743],...
    'String',{'Expected return'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
E1=rf-0.000045;
E2=rf+0.00005;
plot(E(E<E1)*100,RIRCSCbar(E<E1)*100,'--',E(E>E2)*100,RIRCSCbar(E>E2)*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 0 80])

% Relative increase in the ratio of SCVaR in 1994 to SCVaR in Q2 2008-Q1 2009
figure6A = figure;
axes6A = axes('Parent',figure6A,'LineWidth',3,...
    'YTickLabel',{'-10', '0 ','10 ','20 ','30 ','40 ','50 ','60 '},...
    'YTick',[-10 0 10 20 30 40 50 60],...
    'XTickLabel',{'0','0.2','0.4','0.6','0.8','1','1.2'},...
    'XTick',[0 0.2 0.4 0.6 0.8 1],...
    'Position',[0.291666666666667 0.136970954356846 0.680000000000001 0.815],'FontSize',40,...
    'FontName','Times new roman');%% Uncomment the following line to preserve the X-limits of the axes
box(axes6A,'on');
hold(axes6A,'all');
annotation(figure6A,'textbox',...
    [0.0015625 0.761057246393132 0.230208333333333 0.229122055674518],...
    'String',{'Relative change in','the ratio of', 'SCVaRs'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'LineStyle','none');
annotation(figure6A,'textbox',...
    [0.792708333333333 0.00977755162850643 0.1859375 0.0588865096359743],...
    'String',{'Expected return'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(E*100,RCRCshatCs*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 -10 60])

figure6B = figure;
axes6B = axes('Parent',figure6B,'LineWidth',3,...
    'YTickLabel',{'-10', '0 ','10 ','20 ','30 ','40 ','50 ','60 '},...
    'YTick',[-10 0 10 20 30 40 50 60],...
    'XTickLabel',{'0','0.2','0.4','0.6','0.8','1','1.2'},...
    'XTick',[0 0.2 0.4 0.6 0.8 1],...
    'Position',[0.291666666666667 0.136970954356846 0.680000000000001 0.815],'FontSize',40,...
    'FontName','Times new roman');%% Uncomment the following line to preserve the X-limits of the axes
box(axes6B,'on');
hold(axes6B,'all');
annotation(figure6B,'textbox',...
    [0.0015625 0.761057246393132 0.230208333333333 0.229122055674518],...
    'String',{'Relative change in','the ratio of', 'SCVaRs'},...
    'HorizontalAlignment','center',...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'LineStyle','none');
annotation(figure6B,'textbox',...
    [0.792708333333333 0.00977755162850643 0.1859375 0.0588865096359743],...
    'String',{'Expected return'},...
    'FontSize',40,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
E1=rf-0.00013;
E2=rf+0.0001;
plot(E(E<E1)*100,RCRCshatCsbar(E<E1)*100,'--',E(E>E2)*100,RCRCshatCsbar(E>E2)*100,'--','LineWidth',1.5,'Color',[0 0 0]);
axis([0 1 -10 60])

%relative change in MCR arising from using SCVaR instead of both VaR and SVaR
figure7A = figure;
axes7A = axes('Parent',figure7A,'LineWidth',3,...
    'YTickLabel',{'-45 ','-40 ','-35 ','-30 ','-25 ','-20 ','-15 '},...
    'YTick',[-45 -40 -35 -30 -25 -20 -15],...
    'Position',[0.316235119047621 0.142324273414662 0.660476190476189 0.815000000000001],...
    'FontSize',44,...
    'FontName','Times new roman');
box(axes7A,'on');
hold(axes7A,'all');
annotation(figure7A,'textbox',...
     [0.771875 0 0.224999993449698 0.078838172233451],...
    'String',{'Expected return'},...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure7A,'textbox',...
    [0 0.778008298755187 0.246354166666667 0.216320380905825],...
    'String',{'Relative change in','minimum capital','requirement'},...
    'HorizontalAlignment','center',...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(E*100,RCMCREVVs*100,E*100,RCMCRalphaEVVs*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 -45 -15])

%relative change in MCR arising from using SCVaR instead of VaR
figure7B = figure;
axes7B = axes('Parent',figure7B,'LineWidth',3,...
    'YTickLabel',{'0 ','50 ','100 ','150 ','200 '},...
    'YTick',[0 50 100 150 200],...
    'Position',[0.316235119047621 0.142324273414662 0.660476190476189 0.815000000000001],...
    'FontSize',44,...
    'FontName','Times new roman');
box(axes7B,'on');
hold(axes7B,'all');
annotation(figure7B,'textbox',...
     [0.771875 0 0.224999993449698 0.078838172233451],...
    'String',{'Expected return'},...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure7B,'textbox',...
    [0 0.778008298755187 0.246354166666667 0.216320380905825],...
    'String',{'Relative change in','minimum capital','requirement'},...
    'HorizontalAlignment','center',...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(E*100,RCMCREV*100,E*100,RCMCRalphaEV*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 0 200])

%relative change in MCR arising from using SCVaR instead of both VaR and SVaR
figure7C = figure;
axes7C = axes('Parent',figure7C,'LineWidth',3,...
    'YTickLabel',{'-45 ','-40 ','-35 ','-30 ','-25 ','-20 ','-15 '},...
    'YTick',[-45 -40 -35 -30 -25 -20 -15],...
    'Position',[0.316235119047621 0.142324273414662 0.660476190476189 0.815000000000001],...
    'FontSize',44,...
    'FontName','Times new roman');
box(axes7C,'on');
hold(axes7C,'all');
annotation(figure7C,'textbox',...
     [0.771875 0 0.224999993449698 0.078838172233451],...
    'String',{'Expected return'},...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure7C,'textbox',...
    [0 0.778008298755187 0.246354166666667 0.216320380905825],...
    'String',{'Relative change in','minimum capital','requirement'},...
    'HorizontalAlignment','center',...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
E1=rf-0.000045;
E2=rf+0.000045;
plot(E(E<E1)*100,RCMCREVVsbar(E<E1)*100,E(E>E2)*100,RCMCREVVsbar(E>E2)*100,E(E<E1)*100,RCMCRalphaEVVsbar(E<E1)*100,'--',E(E>E2)*100,RCMCRalphaEVVsbar(E>E2)*100,'--','LineWidth',1.5,'Color',[0 0 0]);
axis([0 1 -45 -15])

%relative change in MCR arising from using SCVaR instead of VaR
figure7D = figure;
axes7D = axes('Parent',figure7D,'LineWidth',3,...
    'YTickLabel',{'0 ','50 ','100 ','150 ','200 '},...
    'YTick',[0 50 100 150 200],...
    'Position',[0.316235119047621 0.142324273414662 0.660476190476189 0.815000000000001],...
    'FontSize',44,...
    'FontName','Times new roman');
box(axes7D,'on');
hold(axes7D,'all');
annotation(figure7D,'textbox',...
     [0.771875 0 0.224999993449698 0.078838172233451],...
    'String',{'Expected return'},...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure7D,'textbox',...
    [0 0.778008298755187 0.246354166666667 0.216320380905825],...
    'String',{'Relative change in','minimum capital','requirement'},...
    'HorizontalAlignment','center',...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
E1=rf-0.000045;
E2=rf+0.00006;
plot(E(E<E1)*100,RCMCREVbar(E<E1)*100,E(E>E2)*100,RCMCREVbar(E>E2)*100,E(E<E1)*100,RCMCRalphaEVbar(E<E1)*100,'--',E(E>E2)*100,RCMCRalphaEVbar(E>E2)*100,'--','LineWidth',1.5,'Color',[0 0 0]);
axis([0 1 0 200])

%relative change in MCR from a period not involving the crisis to a period involving one
figure8A = figure;
axes8A = axes('Parent',figure8A,'LineWidth',3,...
    'YTickLabel',{'-20 ','0 ','20 ','40 ','60 ','80 ','100 ','120 '},...
    'YTick',[-20 0 20 40 60 80 100 120],...
    'Position',[0.316235119047621 0.142324273414662 0.660476190476189 0.815000000000001],...
    'FontSize',44,...
    'FontName','Times new roman');
box(axes8A,'on');
hold(axes8A,'all');
annotation(figure8A,'textbox',...
     [0.771875 0 0.224999993449698 0.078838172233451],...
    'String',{'Expected return'},...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure8A,'textbox',...
    [0 0.778008298755187 0.246354166666667 0.216320380905825],...
    'String',{'Relative change in','minimum capital','requirement'},...
    'HorizontalAlignment','center',...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(E*100,RCMCREVhatVsVVs*100,E*100,RCMCRalphaEVhatVsVVs*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 -20 100])

%relative change in MCR from a period not involving the crisis to a period involving one
figure8B = figure;
axes8B = axes('Parent',figure8B,'LineWidth',3,...
    'YTickLabel',{'-20 ','0 ','20 ','40 ','60 ','80 ','100 '},...
    'YTick',[-20 0 20 40 60 80 100 120],...
    'Position',[0.316235119047621 0.142324273414662 0.660476190476189 0.815000000000001],...
    'FontSize',44,...
    'FontName','Times new roman');
box(axes8B,'on');
hold(axes8B,'all');
annotation(figure8B,'textbox',...
     [0.771875 0 0.224999993449698 0.078838172233451],...
    'String',{'Expected return'},...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure8B,'textbox',...
    [0 0.778008298755187 0.246354166666667 0.216320380905825],...
    'String',{'Relative change in','minimum capital','requirement'},...
    'HorizontalAlignment','center',...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
plot(E*100,RCMCREVhatV*100,E*100,RCMCRalphaEVhatV*100,'--','LineWidth',1.5,'Color',[0 0 0])
axis([0 1 -20 100])

%relative change in MCR from a period not involving the crisis to a period involving one
figure8C = figure;
axes8C = axes('Parent',figure8C,'LineWidth',3,...
    'YTickLabel',{'-20 ','0 ','20 ','40 ','60 ','80 ','100 ','120 '},...
    'YTick',[-20 0 20 40 60 80 100 120],...
    'Position',[0.316235119047621 0.142324273414662 0.660476190476189 0.815000000000001],...
    'FontSize',44,...
    'FontName','Times new roman');
box(axes8C,'on');
hold(axes8C,'all');
annotation(figure8C,'textbox',...
     [0.771875 0 0.224999993449698 0.078838172233451],...
    'Interpreter','none',...
    'String',{'Expected return'},...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure8C,'textbox',...
    [0 0.778008298755187 0.246354166666667 0.216320380905825],...
    'String',{'Relative change in','minimum capital','requirement'},...
    'HorizontalAlignment','center',...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
E1=rf-0.00006;
E2=rf+0.00006;
plot(E(E<E1)*100,RCMCREVhatVsVVsbar(E<E1)*100,E(E>E2)*100,RCMCREVhatVsVVsbar(E>E2)*100,E(E<E1)*100,RCMCRalphaEVhatVsVVsbar(E<E1)*100,'--',E(E>E2)*100,RCMCRalphaEVhatVsVVsbar(E>E2)*100,'--','LineWidth',1.5,'Color',[0 0 0]);
axis([0 1 -20 100])

%relative change in MCR from a period not involving the crisis to a period involving one
figure8D = figure;
axes8D = axes('Parent',figure8D,'LineWidth',3,...
    'YTickLabel',{'-20 ','0 ','20 ','40 ','60 ','80 ','100 ','120 '},...
    'YTick',[-20 0 20 40 60 80 100 120],...
    'Position',[0.316235119047621 0.142324273414662 0.660476190476189 0.815000000000001],...
    'FontSize',44,...
    'FontName','Times new roman');
box(axes8D,'on');
hold(axes8D,'all');
annotation(figure8D,'textbox',...
     [0.771875 0 0.224999993449698 0.078838172233451],...
    'Interpreter','none',...
    'String',{'Expected return'},...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
annotation(figure8D,'textbox',...
    [0 0.778008298755187 0.246354166666667 0.216320380905825],...
    'String',{'Relative change in','minimum capital','requirement'},...
    'HorizontalAlignment','center',...
    'FontSize',44,...
    'FontName','Times New Roman',...
    'FitBoxToText','off',...
    'LineStyle','none');
E1=rf-0.00015;
E2=rf+0.00015;
plot(E(E<E1)*100,RCMCREVhatVbar(E<E1)*100,E(E>E2)*100,RCMCREVhatVbar(E>E2)*100,E(E<E1)*100,RCMCRalphaEVhatVbar(E<E1)*100,'--',E(E>E2)*100,RCMCRalphaEVhatVbar(E>E2)*100,'--','LineWidth',1.5,'Color',[0 0 0]);
axis([0 1 -20 100])

end